@@ -221,6 +221,7 @@ def generate(
     encoding: str = 'utf-8',
     enum_field_as_literal: Optional[LiteralType] = None,
     set_default_enum_member: bool = False,
+    use_subclass_enum: bool = False,
     strict_nullable: bool = False,
     use_generic_container_types: bool = False,
     enable_faux_immutability: bool = False,
@@ -340,6 +341,7 @@ def generate(
         reuse_model=reuse_model,
         enum_field_as_literal=enum_field_as_literal,
         set_default_enum_member=set_default_enum_member,
+        use_subclass_enum=use_subclass_enum,
         strict_nullable=strict_nullable,
         use_generic_container_types=use_generic_container_types,
         enable_faux_immutability=enable_faux_immutability,
