@@ -159,6 +159,16 @@ def sort_data_models(
             unresolved_model = (
                 model.reference_classes - {model.path} - set(sorted_data_models)
             )
+            base_models = [
+                getattr(s.reference, "path", None) for s in model.base_classes
+            ]
+            update_action_parent = set(require_update_action_models).intersection(
+                base_models
+            )
+            if not unresolved_model and update_action_parent:
+                sorted_data_models[model.path] = model
+                require_update_action_models.append(model.path)
+                continue
             if not unresolved_model:
                 sorted_data_models[model.path] = model
                 continue
@@ -270,6 +280,7 @@ class Parser(ABC):
         encoding: str = 'utf-8',
         enum_field_as_literal: Optional[LiteralType] = None,
         set_default_enum_member: bool = False,
+        use_subclass_enum: bool = False,
         strict_nullable: bool = False,
         use_generic_container_types: bool = False,
         enable_faux_immutability: bool = False,
@@ -320,6 +331,7 @@ class Parser(ABC):
         self.encoding: str = encoding
         self.enum_field_as_literal: Optional[LiteralType] = enum_field_as_literal
         self.set_default_enum_member: bool = set_default_enum_member
+        self.use_subclass_enum: bool = use_subclass_enum
         self.strict_nullable: bool = strict_nullable
         self.use_generic_container_types: bool = use_generic_container_types
         self.enable_faux_immutability: bool = enable_faux_immutability
